Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/Duet3D/RepRapFirmware.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDavid Crocker <dcrocker@eschertech.com>2016-11-19 12:58:13 +0300
committerDavid Crocker <dcrocker@eschertech.com>2016-11-19 12:58:45 +0300
commit59dd1b2dc56ebd35c936e4722cdc76e03fc301f2 (patch)
treea9126c6ad4878667beddd022b6ab3cdc2ff2acf3 /src/Configuration.h
parent4669a36386a0c8530a0d39e3bfa7601afacc3fdd (diff)
Version 1.17dev4
Added support for M557 grid definition and G29 grid probing (not complete yet) Workaround for DWC sending volume ID in new name when renaming a file across directories G1 moves with S2 modifier no longer ad the tool offset
Diffstat (limited to 'src/Configuration.h')
-rw-r--r--src/Configuration.h21
1 files changed, 14 insertions, 7 deletions
diff --git a/src/Configuration.h b/src/Configuration.h
index f3947989..40d2b9e5 100644
--- a/src/Configuration.h
+++ b/src/Configuration.h
@@ -28,11 +28,11 @@ Licence: GPL
// Firmware name is now defined in the Pins file
#ifndef VERSION
-# define VERSION "1.17dev4"
+# define VERSION "1.17dev5"
#endif
#ifndef DATE
-# define DATE "2016-11-17"
+# define DATE "2016-11-19"
#endif
#define AUTHORS "reprappro, dc42, zpl, t3p3, dnewman"
@@ -124,16 +124,23 @@ const unsigned int DefaultPinWritePwmFreq = 500; // default PWM frequency for M4
// The maximum number of probe points is constrained by RAM usage:
// - Each probe point uses 12 bytes of static RAM. So 16 points use 192 bytes
// - The delta probe points use the same static ram, but when auto-calibrating we temporarily need another 44 bytes per probe point to hold the matrices etc.
// So 16 points need 704 bytes of stack space.
#ifdef DUET_NG
-const size_t MAX_PROBE_POINTS = 64; // Maximum number of probe points
-const size_t MAX_DELTA_PROBE_POINTS = 64; // Must be <= MaxProbePoints, may be smaller to reduce matrix storage requirements. Preferably a power of 2.
+const size_t MaxGridProbePoints = 441; // 441 allows us to probe e.g. 400x400 at 20mm intervals
+const size_t MaxProbePoints = 64; // Maximum number of probe points
+const size_t MaxDeltaCalibrationPoints = 64; // Should a power of 2 for speed
#else
-const size_t MAX_PROBE_POINTS = 32; // Maximum number of probe points
-const size_t MAX_DELTA_PROBE_POINTS = 32; // Must be <= MaxProbePoints, may be smaller to reduce matrix storage requirements. Preferably a power of 2.
+const size_t MaxGridProbePoints = 121; // 121 allows us to probe 200x200 at 20mm intervals
+const size_t MaxProbePoints = 32; // Maximum number of probe points
+const size_t MaxDeltaCalibrationPoints = 32; // Should a power of 2 for speed
#endif
+const float DefaultGridSpacing = 20.0; // Default bed probing grid spacing in mm
+
+static_assert(MaxProbePoints <= MaxGridProbePoints, "MaxProbePoints must be <= MaxGridProbePoints");
+static_assert(MaxDeltaCalibrationPoints <= MaxProbePoints, "MaxDeltaCalibrationPoints must be <= MaxProbePoints");
+
const float DEFAULT_Z_DIVE = 5.0; // Millimetres
const float DEFAULT_PROBE_SPEED = 2.0; // Default Z probing speed mm/sec
const float DEFAULT_TRAVEL_SPEED = 100.0; // Default speed for travel to probe points
@@ -124,16 +124,23 @@ const unsigned int DefaultPinWritePwmFreq = 500; // default PWM frequency for M4
// The maximum number of probe points is constrained by RAM usage:
// - Each probe point uses 12 bytes of static RAM. So 16 points use 192 bytes
-// - The delta probe points use the same static ram, but when auto-calibrating we temporarily need another 44 bytes per probe point to hold the matrices etc.
+// - The delta calibration points use the same static ram, but when auto-calibrating we temporarily need another 44 bytes per calibration point to hold the matrices etc.
// So 16 points need 704 bytes of stack space.
#ifdef DUET_NG